@@ -1,8 +1,8 @@
-"neweS" <-
+# Converts a data matrix into an ExpressionSet object.
+neweS <-
 function(mat, vlist, vlabel=as.list(names(vlist))) {
   names(vlabel) <- names(vlist)
 
-  #Must add appropriate names to the variables in vlist for R 2.3 compatibility.
   for (i in 1:length(vlist)) {
     names(vlist[[i]]) <- colnames(mat)
   }
