@@ -1,4 +1,5 @@
-"norm" <-
+#Normalizes a matrix by subtracting the column (sample) mean #from each element and adding the grand mean.
+norm <-
 function(mat1)
 {
   mat2 <- as.matrix(mat1)
